Module apputils::config

source ·
Config file helpers

Functions to aid in loading and managing config files.

What you’d want to use 99% of the time is either cascade or local_file, depending on if your app should also read global config files.

Functions